==> script.module.liptonscrapers-1.1.07.zip: script.module.liptonscrapers/lib/liptonscrapers/sources_ Liptonmodule/en/projectfreetv.py <==
# -*- coding: utf-8 -*-
############################################################################################################################################################################                                                                                                                                       #                                                                                                                                                                          #
#                                                                                                                                                                          #
#    ##     .   **       #########.  ########   #########   ##     ##    #########   #########   #########   #########   #########   ########   #########   ##########     #
#    ##         ##       ##     ##     ###      ##     ##   ###    ##    ##          ##          ##     ##   ##     ##   ##     ##   ##         ##     ##   ##             #
#    ##         ##       ##     ##     ###      ##     ##   ## #   ##    ##          ##          ##     ##   ##     ##   ##     ##   ##         ##     ##   ##             #
#    ##         ##       ########      ###      ##     ##   ##  #  ##    #########   ##          ########    #########   ## ######   ########   ########    ##########     #
#    ##         ##       ##            ###      ##     ##   ##   # ##           ##   ##          ##    ##    ##     ##   ##          ##         ##    ##            ##     #
#    ##         ##       ##            ###      ##     ##   ##    ###           ##   ##          ##     ##   ##     ##   ##          ##         ##     ##           ##     #
#    #######    ##       ##     .      ###      #########   ##     ##    #########   ##########  ##      #   ##     ##   ##          ########   ##      #   ##########     #
############################################################################################################################################################################
import re

from liptonscrapers.modules import cfscrape
from liptonscrapers.modules import cleantitle
from liptonscrapers.modules import source_utils


class source:
	def __init__(self):
		self.priority = 1
		self.language = ['en']
		self.domains = ['projectfreetv.ag']
		self.base_link = 'http://www1.projectfreetv.ag'
		self.search_link = '/episode/%s-season-%s-episode-%s'
		self.scraper = cfscrape.create_scraper()

	def tvshow(self, imdb, tvdb, tvshowtitle, localtvshowtitle, aliases, year):
		try:
			clean_title = cleantitle.geturl(tvshowtitle)
			url = clean_title
			return url
		except:
			return

	def episode(self, url, imdb, tvdb, title, premiered, season, episode):
		try:
			if not url:
				return
			tvshowtitle = url
			url = self.base_link + self.search_link % (tvshowtitle, int(season), int(episode))
			return url
		except:
			return

	def sources(self, url, hostDict, hostprDict):
		try:
			sources = []
			r = self.scraper.get(url).content
			try:
				data = re.compile("callvalue\('.+?','.+?','(.+?)://(.+?)/(.+?)'\)", re.DOTALL).findall(r)
				for http, host, url in data:
					url = '%s://%s/%s' % (http, host, url)
					quality, info = source_utils.get_release_quality(url)
					sources.append({
						'source': host,
						'quality': quality,
						'language': 'en',
						'url': url,
						'info': info,
						'direct': False,
						'debridonly': False
					})
			except:
				pass
			return sources
		except Exception:
			return

	def resolve(self, url):
		return url

==> script.module.liptonscrapers-1.1.10.zip: script.module.liptonscrapers/lib/liptonscrapers/sources_ Liptonmodule/en/projectfreetv.py <==
# -*- coding: utf-8 -*-

'''
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import re

from liptonscrapers.modules import cfscrape
from liptonscrapers.modules import cleantitle
from liptonscrapers.modules import source_utils


class source:
	def __init__(self):
		self.priority = 1
		self.language = ['en']
		self.domains = ['projectfreetv.ag']
		self.base_link = 'http://www1.projectfreetv.ag'
		self.search_link = '/episode/%s-season-%s-episode-%s'
		self.scraper = cfscrape.create_scraper()

	def tvshow(self, imdb, tvdb, tvshowtitle, localtvshowtitle, aliases, year):
		try:
			clean_title = cleantitle.geturl(tvshowtitle)
			url = clean_title
			return url
		except:
			return

	def episode(self, url, imdb, tvdb, title, premiered, season, episode):
		try:
			if not url:
				return
			tvshowtitle = url
			url = self.base_link + self.search_link % (tvshowtitle, int(season), int(episode))
			return url
		except:
			return

	def sources(self, url, hostDict, hostprDict):
		try:
			sources = []
			r = self.scraper.get(url).content
			try:
				data = re.compile("callvalue\('.+?','.+?','(.+?)://(.+?)/(.+?)'\)", re.DOTALL).findall(r)
				for http, host, url in data:
					url = '%s://%s/%s' % (http, host, url)
					quality, info = source_utils.get_release_quality(url)
					sources.append({
						'source': host,
						'quality': quality,
						'language': 'en',
						'url': url,
						'info': info,
						'direct': False,
						'debridonly': False
					})
			except:
				pass
			return sources
		except Exception:
			return

	def resolve(self, url):
		return url
